@@ -20,7 +20,7 @@ from elftools.elf.constants import SH_FLAGS
 
 
 __author__ = 'Erik Moqvist'
-__version__ = '17.14.5'
+__version__ = '19.0.0'
 
 
 DEFAULT_WORD_SIZE_BITS = 8
@@ -346,36 +346,33 @@ def is_verilog_vmem(data):
         return True
 
 
-class _Segment:
+class Segment:
     """A segment is a chunk data with given minimum and maximum address.
 
     """
 
-    _Chunk = namedtuple('Chunk', ['address', 'data'])
-
     def __init__(self, minimum_address, maximum_address, data, word_size_bytes):
         self.minimum_address = minimum_address
         self.maximum_address = maximum_address
         self.data = data
-        self._word_size_bytes = word_size_bytes
+        self.word_size_bytes = word_size_bytes
 
     @property
     def address(self):
-        return self.minimum_address // self._word_size_bytes
+        return self.minimum_address // self.word_size_bytes
 
     def chunks(self, size=32, alignment=1):
         """Return chunks of the data aligned as given by `alignment`. `size`
-        must be a multiple of `alignment`. Each chunk is returned as a
-        named two-tuple of its address and data. Both `size` and
-        `alignment` are in words.
+        must be a multiple of `alignment`. Each chunk is itself a Segment.
+        Both `size` and `alignment` are in words.
 
         """
 
         if (size % alignment) != 0:
             raise Error(f'size {size} is not a multiple of alignment {alignment}')
 
-        size *= self._word_size_bytes
-        alignment *= self._word_size_bytes
+        size *= self.word_size_bytes
+        alignment *= self.word_size_bytes
         address = self.minimum_address
         data = self.data
 
@@ -384,16 +381,20 @@ class _Segment:
 
         if chunk_offset != 0:
             first_chunk_size = (alignment - chunk_offset)
-            yield self._Chunk(address // self._word_size_bytes,
-                              data[:first_chunk_size])
-            address += (first_chunk_size // self._word_size_bytes)
+            yield Segment(address,
+                          address + size,
+                          data[:first_chunk_size],
+                          self.word_size_bytes)
+            address += first_chunk_size
             data = data[first_chunk_size:]
         else:
             first_chunk_size = 0
 
         for offset in range(0, len(data), size):
-            yield self._Chunk((address + offset) // self._word_size_bytes,
-                              data[offset:offset + size])
+            yield Segment(address + offset,
+                          address + offset + size,
+                          data[offset:offset + size],
+                          self.word_size_bytes)
 
     def add_data(self, minimum_address, maximum_address, data, overwrite):
         """Add given data to this segment. The added data must be adjacent to
@@ -464,10 +465,10 @@ class _Segment:
             self.maximum_address = self.minimum_address + part1_size
             self.data = part1_data
 
-            return _Segment(maximum_address,
-                            maximum_address + len(part2_data),
-                            part2_data,
-                            self._word_size_bytes)
+            return Segment(maximum_address,
+                           maximum_address + len(part2_data),
+                           part2_data,
+                           self.word_size_bytes)
         else:
             # Update this segment.
             if len(part1_data) > 0:
@@ -483,11 +484,11 @@ class _Segment:
     def __eq__(self, other):
         if isinstance(other, tuple):
             return self.address, self.data == other
-        elif isinstance(other, _Segment):
+        elif isinstance(other, Segment):
             return ((self.minimum_address == other.minimum_address)
                     and (self.maximum_address == other.maximum_address)
                     and (self.data == other.data)
-                    and (self._word_size_bytes == other._word_size_bytes))
+                    and (self.word_size_bytes == other.word_size_bytes))
         else:
             return False
 
@@ -499,14 +500,20 @@ class _Segment:
     def __repr__(self):
         return f'Segment(address={self.address}, data={self.data})'
 
+    def __len__(self):
+        return len(self.data) // self.word_size_bytes
 
-class _Segments:
+
+_Segment = Segment
+
+
+class Segments:
     """A list of segments.
 
     """
 
     def __init__(self, word_size_bytes):
-        self._word_size_bytes = word_size_bytes
+        self.word_size_bytes = word_size_bytes
         self._current_segment = None
         self._current_segment_index = None
         self._list = []
@@ -628,9 +635,8 @@ class _Segments:
     def chunks(self, size=32, alignment=1):
         """Iterate over all segments and return chunks of the data aligned as
         given by `alignment`. `size` must be a multiple of
-        `alignment`. Each chunk is returned as a named two-tuple of
-        its address and data. Both `size` and `alignment` are in
-        words.
+        `alignment`. Each chunk is in turn a smaller Segment. Both `size` and
+        `alignment` are in words.
 
         """
 
@@ -649,6 +655,9 @@ class _Segments:
         return len(self._list)
 
 
+_Segments = Segments
+    
+
 class BinFile:
     """A binary file.
 
@@ -682,7 +691,7 @@ class BinFile:
         self._header_encoding = header_encoding
         self._header = None
         self._execution_start_address = None
-        self._segments = _Segments(self.word_size_bytes)
+        self._segments = Segments(self.word_size_bytes)
 
         if filenames is not None:
             if isinstance(filenames, str):
@@ -832,10 +841,10 @@ class BinFile:
         >>> for chunk in binfile.segments.chunks(2):
         ...     print(chunk)
         ...
-        Chunk(address=0, data=bytearray(b'\\x00\\x01'))
-        Chunk(address=2, data=bytearray(b'\\x02'))
-        Chunk(address=10, data=bytearray(b'\\x03\\x04'))
-        Chunk(address=12, data=bytearray(b'\\x05'))
+        Segment(address=0, data=bytearray(b'\\x00\\x01'))
+        Segment(address=2, data=bytearray(b'\\x02'))
+        Segment(address=10, data=bytearray(b'\\x03\\x04'))
+        Segment(address=12, data=bytearray(b'\\x05'))
 
         Each segment can be split into smaller pieces using the
         `chunks(size=32, alignment=1)` method on a single segment.
@@ -846,11 +855,11 @@ class BinFile:
         ...         print(chunk)
         ...
         Segment(address=0, data=bytearray(b'\\x00\\x01\\x02'))
-        Chunk(address=0, data=bytearray(b'\\x00\\x01'))
-        Chunk(address=2, data=bytearray(b'\\x02'))
+        Segment(address=0, data=bytearray(b'\\x00\\x01'))
+        Segment(address=2, data=bytearray(b'\\x02'))
         Segment(address=10, data=bytearray(b'\\x03\\x04\\x05'))
-        Chunk(address=10, data=bytearray(b'\\x03\\x04'))
-        Chunk(address=12, data=bytearray(b'\\x05'))
+        Segment(address=10, data=bytearray(b'\\x03\\x04'))
+        Segment(address=12, data=bytearray(b'\\x05'))
 
         """
 
@@ -893,10 +902,10 @@ class BinFile:
                 self._header = data
             elif type_ in '123':
                 address *= self.word_size_bytes
-                self._segments.add(_Segment(address,
-                                            address + size,
-                                            data,
-                                            self.word_size_bytes),
+                self._segments.add(Segment(address,
+                                           address + size,
+                                           data,
+                                           self.word_size_bytes),
                                    overwrite)
             elif type_ in '789':
                 self.execution_start_address = address
@@ -924,10 +933,10 @@ class BinFile:
                            + extended_segment_address
                            + extended_linear_address)
                 address *= self.word_size_bytes
-                self._segments.add(_Segment(address,
-                                            address + size,
-                                            data,
-                                            self.word_size_bytes),
+                self._segments.add(Segment(address,
+                                           address + size,
+                                           data,
+                                           self.word_size_bytes),
                                    overwrite)
             elif type_ == IHEX_END_OF_FILE:
                 pass
@@ -987,10 +996,10 @@ class BinFile:
                 if address is None:
                     raise Error("missing section address")
 
-                self._segments.add(_Segment(address,
-                                            address + size,
-                                            data,
-                                            self.word_size_bytes),
+                self._segments.add(Segment(address,
+                                           address + size,
+                                           data,
+                                           self.word_size_bytes),
                                    overwrite)
 
                 if size == TI_TXT_BYTES_PER_LINE:
@@ -1025,10 +1034,10 @@ class BinFile:
         for word in words:
             if word.startswith('@'):
                 if address is not None:
-                    self._segments.add(_Segment(address,
-                                                address + len(chunk),
-                                                chunk,
-                                                self.word_size_bytes))
+                    self._segments.add(Segment(address,
+                                               address + len(chunk),
+                                               chunk,
+                                               self.word_size_bytes))
 
                 address = int(word[1:], 16) * word_size_bytes
                 chunk = b''
@@ -1036,10 +1045,10 @@ class BinFile:
                 chunk += bytes.fromhex(word)
 
         if address is not None and chunk:
-            self._segments.add(_Segment(address,
-                                        address + len(chunk),
-                                        chunk,
-                                        self.word_size_bytes))
+            self._segments.add(Segment(address,
+                                       address + len(chunk),
+                                       chunk,
+                                       self.word_size_bytes))
 
     def add_binary(self, data, address=0, overwrite=False):
         """Add given data at given address. Set `overwrite` to ``True`` to
@@ -1048,10 +1057,10 @@ class BinFile:
         """
 
         address *= self.word_size_bytes
-        self._segments.add(_Segment(address,
-                                    address + len(data),
-                                    bytearray(data),
-                                    self.word_size_bytes),
+        self._segments.add(Segment(address,
+                                   address + len(data),
+                                   bytearray(data),
+                                   self.word_size_bytes),
                            overwrite)
 
     def add_elf(self, data, overwrite=True):
@@ -1086,10 +1095,10 @@ class BinFile:
                     if (section['sh_flags'] & SH_FLAGS.SHF_ALLOC) == 0:
                         continue
 
-                    self._segments.add(_Segment(address,
-                                                address + size,
-                                                data[offset:offset + size],
-                                                self.word_size_bytes),
+                    self._segments.add(Segment(address,
+                                               address + size,
+                                               data[offset:offset + size],
+                                               self.word_size_bytes),
                                        overwrite)
 
     def add_file(self, filename, overwrite=False):
@@ -1610,7 +1619,7 @@ class BinFile:
                 fill_size_words = fill_size // self.word_size_bytes
 
                 if max_words is None or fill_size_words <= max_words:
-                    fill_segments.append(_Segment(
+                    fill_segments.append(Segment(
                         previous_segment_maximum_address,
                         previous_segment_maximum_address + fill_size,
                         value * fill_size_words,
